@@ -83,6 +83,7 @@ sorted_classifiers = [
     "Framework :: CherryPy",
     "Framework :: CubicWeb",
     "Framework :: Dash",
+    "Framework :: Datasette",
     "Framework :: Django",
     "Framework :: Django :: 1.4",
     "Framework :: Django :: 1.5",
@@ -105,6 +106,7 @@ sorted_classifiers = [
     "Framework :: Django CMS :: 3.6",
     "Framework :: Django CMS :: 3.7",
     "Framework :: Django CMS :: 3.8",
+    "Framework :: FastAPI",
     "Framework :: Flake8",
     "Framework :: Flask",
     "Framework :: Hypothesis",
@@ -783,6 +785,7 @@ sorted_classifiers = [
     "Topic :: Text Processing :: Markup :: XML",
     "Topic :: Text Processing :: Markup :: reStructuredText",
     "Topic :: Utilities",
+    "Typing :: Stubs Only",
     "Typing :: Typed",
 ]
 
